@@ -1,11 +1,6 @@
 #ifndef IGR_H_
 #define IGR_H_
 
-#include <vector>
-#include <cmath>
-#include <cstdlib>
-#include <iterator>
-
 #if defined WSRF_USE_BOOST || defined WSRF_USE_C11
 #ifdef WSRF_USE_BOOST
 #include <boost/random/mersenne_twister.hpp>
@@ -22,7 +17,9 @@ using namespace std;
 class IGR {
 private:
     int nvars_;  //subspace size
+#if defined WSRF_USE_BOOST || defined WSRF_USE_C11
     unsigned seed_;
+#endif
 
     vector<double> weights_;
     vector<int>    wst_;
@@ -31,9 +28,13 @@ private:
 
 
     int weightedSampling(int random_integer);
-    vector<int> getRandomWeightedVars();
+    inline vector<int> getRandomWeightedVars();
 public:
+#if defined WSRF_USE_BOOST || defined WSRF_USE_C11
     IGR(const vector<double>& gain_ratio, int nvars, unsigned seed);
+#else
+    IGR(const vector<double>& gain_ratio, int nvars);
+#endif
 
     void normalizeWeight(volatile bool* pInterrupt);
     int  getSelectedIdx();
